taperable\_helix package
========================

..
   Using autofunction:: instead of automodule:: produces
   better output:

   With automodule the name is taperable_helix.helix.helix.
   With autofunciton it's taperable_helix.helix.


.. autofunction:: taperable_helix.helix

..
   Module contents
   ---------------

   .. automodule:: taperable_helix
      :members:
      :undoc-members:
      :show-inheritance:
